/* Create database : GuideMaker       */
CONNECT "GuideMaker.gdb" ;

/***********************************/
/*              Domains            */
/***********************************/

CREATE DOMAIN TMEMO AS BLOB SUB_TYPE 1 SEGMENT SIZE 80;

CREATE DOMAIN TID AS INTEGER;

CREATE DOMAIN TSTRING AS VARCHAR(255);

CREATE DOMAIN TDATETIME AS DATE;

CREATE DOMAIN TBOOLEAN AS CHAR(1) DEFAULT 'N' NOT NULL CHECK (VALUE IN ('Y','N'));

CREATE DOMAIN TSTRINGID AS VARCHAR(10);

/***********************************/
/*              Tables             */
/***********************************/

/* Table: MASTER_DETAIL  */
CREATE TABLE MASTER_DETAIL (
       MASTER_ID TID NOT NULL,
       DETAIL_ID TID NOT NULL,
       ORDER_ INTEGER,
      CONSTRAINT MASTER_DETAIL_PK PRIMARY KEY (MASTER_ID,DETAIL_ID)
);

CREATE INDEX MASTER_DETAIL_ORDER ON MASTER_DETAIL(MASTER_ID, DETAIL_ID, ORDER_);

/* Table: NODE  */
CREATE TABLE NODE (
       NODE_ID TID NOT NULL,
       TITLE TSTRING NOT NULL,
       BODY TMEMO,
       HEAD TMEMO,
       ENCODING VARCHAR(30),
       STAMP_CREATED TDATETIME DEFAULT 'NOW' NOT NULL,
       STAMP_UPDATED TDATETIME DEFAULT 'NOW' NOT NULL,
       ORIG_URL TSTRING,
       ORIG_ID TSTRING,
       READ_CONTENT TBOOLEAN NOT NULL,
       GUIDE_TYPE TSTRINGID,
      CONSTRAINT NODE_PK PRIMARY KEY (NODE_ID)
);

/* Table: TEMPLATE  */
CREATE TABLE TEMPLATE (
       GUIDE_TYPE TSTRINGID DEFAULT 'DEFAULT' NOT NULL,
       KIND TSTRINGID DEFAULT 'DEFAULT' NOT NULL,
       TEXT TMEMO,
      CONSTRAINT TEMPLATE_PK PRIMARY KEY (GUIDE_TYPE,KIND)
);

/*---------------------------*/
/*  Foreign Key Definitions  */
/*---------------------------*/
ALTER TABLE MASTER_DETAIL ADD CONSTRAINT MASTER_DETAIL_DETAIL_ID_FK FOREIGN KEY (DETAIL_ID) REFERENCES NODE(NODE_ID) ON UPDATE CASCADE ON DELETE CASCADE;
ALTER TABLE MASTER_DETAIL ADD CONSTRAINT MASTER_DETAIL_MASTER_ID_FK FOREIGN KEY (MASTER_ID) REFERENCES NODE(NODE_ID) ON UPDATE CASCADE ON DELETE CASCADE;

/*  Check Constraints  */
/***********************************/
/*             Generators          */
/***********************************/

CREATE GENERATOR NODE_ID;

SET GENERATOR NODE_ID TO 2604;

COMMIT WORK;
SET TERM ^ ;
/***********************************/
/*              Triggers           */
/***********************************/

CREATE TRIGGER TG_AD_MASTER_DEATAIL_DETAIL FOR MASTER_DETAIL
ACTIVE AFTER DELETE POSITION 0
AS
     declare variable N Integer;
begin
  SELECT COUNT(*) FROM MASTER_DETAIL WHERE DETAIL_ID=OLD.DETAIL_ID
  INTO N;
  IF (N = 0 AND OLD.DETAIL_ID > 0) THEN
  BEGIN
    DELETE FROM NODE WHERE NODE_ID=OLD.DETAIL_ID;
  END

end
 ^

COMMIT WORK^
SET TERM ; ^
